"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const block_info_1 = require("block-info");
const _ = require("lodash");
const visit = require("unist-util-visit");
const types_1 = require("../types");
const utils_1 = require("../utils");
exports.default = () => (ast, vFile) => {
    const idPrefix = utils_1.getLabelIdPrefix(vFile);
    let idIndex = 0;
    return visit(ast, "narrativeSchemaLabel", (labelNode) => {
        const parsedInfo = block_info_1.parse(labelNode.data.info);
        const labelName = parsedInfo.language;
        const labelType = labelNode.data.labelType;
        const labelAttributes = parsedInfo.attributes;
        labelNode.labelName = labelName;
        labelNode.data.labelName = labelName;
        labelNode.data.labelAttributes = labelAttributes;
        // id helps litvis-integration-mume match labels in uniast
        // with the ones it finds in markdown-it tree
        labelNode.data.id = `${idPrefix}-${idIndex}`;
        idIndex += 1;
        if (!labelName) {
            utils_1.markLabelNodeAsErroneous(vFile, labelNode, types_1.LabelErrorType.BLANK, `Label cannot be blank.`);
            return;
        }
        if (labelType === types_1.LabelType.INVALID) {
            utils_1.markLabelNodeAsErroneous(vFile, labelNode, types_1.LabelErrorType.INVALID, `Label ${labelName} is neither single nor paired, please change the endings.`);
            return;
        }
        if (labelType === types_1.LabelType.PAIRED_CLOSING && !_.isEmpty(labelAttributes)) {
            utils_1.markLabelNodeAsErroneous(vFile, labelNode, types_1.LabelErrorType.CLOSING_WITH_ATTRIBUTES, `A closing paired label cannot have attributes.`);
            return;
        }
    });
};
//# sourceMappingURL=extractDerivatives.js.map