"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const visit = require("unist-util-visit");
const types_1 = require("../types");
const utils_1 = require("../utils");
exports.default = () => (ast, vFile) => {
    return visit(ast, "narrativeSchemaLabel", (labelNode, index, parent) => {
        if (labelNode.data.errorType ||
            (labelNode.data.labelType !== types_1.LabelType.PAIRED_OPENING &&
                labelNode.data.labelType !== types_1.LabelType.PAIRED_CLOSING)) {
            return;
        }
        if (!labelNode.data.pairedId) {
            const caption = `Could not find a matching ${labelNode.data.labelType === types_1.LabelType.PAIRED_OPENING
                ? "closing"
                : "opening"} label for ${labelNode.data.labelName}. ${labelNode.data.placement === types_1.LabelPlacement.BLOCK
                ? "This label is placed as block, so the match cannot be surrounded by inline elements and must be padded by empty lines."
                : "This label is inline, so the match must be located within the same paragraph and in the same inline element (if any)."}`;
            utils_1.markLabelNodeAsErroneous(vFile, labelNode, types_1.LabelErrorType.BROKEN_PAIR, caption);
        }
    });
};
//# sourceMappingURL=inspectBrokenPairs.js.map