"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const visit = require("unist-util-visit");
const types_1 = require("../types");
const utils_1 = require("../utils");
exports.default = () => (ast, vFile) => {
    return visit(ast, "narrativeSchemaLabel", (labelNode, index, parent) => {
        if (labelNode.data.errorType ||
            labelNode.data.labelType !== types_1.LabelType.PAIRED_OPENING) {
            return;
        }
        const nestedOpenLabelNodes = [];
        for (let i = index + 1; i < parent.children.length; i += 1) {
            const possibleMatch = parent.children[i];
            if (possibleMatch.type !== "narrativeSchemaLabel") {
                continue;
            }
            if (possibleMatch.data.labelType === types_1.LabelType.PAIRED_CLOSING &&
                possibleMatch.data.labelName === labelNode.data.labelName &&
                !possibleMatch.data.errorType &&
                !possibleMatch.data.pairedId) {
                possibleMatch.data.pairedId = labelNode.data.id;
                labelNode.data.pairedId = possibleMatch.data.id;
                break;
            }
            if (possibleMatch.data.labelType === types_1.LabelType.PAIRED_OPENING) {
                if (possibleMatch.data.pairedId) {
                    nestedOpenLabelNodes.unshift(possibleMatch);
                }
                else {
                    utils_1.markLabelNodeAsErroneous(vFile, labelNode, types_1.LabelErrorType.BROKEN_NESTING, "There is an issue with pairing labels with each other. Make sure all labels are correctly nested and spelled.");
                    break;
                }
            }
            if (possibleMatch.data.labelType === types_1.LabelType.PAIRED_CLOSING) {
                if (!nestedOpenLabelNodes.length ||
                    nestedOpenLabelNodes[0].data.pairedId !== possibleMatch.data.id) {
                    utils_1.markLabelNodeAsErroneous(vFile, labelNode, types_1.LabelErrorType.BROKEN_NESTING, "There is an issue with pairing labels with each other. Make sure all labels are correctly nested and spelled.");
                    break;
                }
                else {
                    nestedOpenLabelNodes.shift();
                }
            }
        }
    }, true /* reverse */);
};
//# sourceMappingURL=pair.js.map