"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const visit = require("unist-util-visit");
const renderHtmlTemplate_1 = require("../renderHtmlTemplate");
const types_1 = require("../types");
const utils_1 = require("../utils");
exports.default = (ast, vFile, labelDefinitionsByName) => {
    return visit(ast, "narrativeSchemaLabel", (labelNode) => {
        if (labelNode.data.errorType) {
            return;
        }
        const labelType = labelNode.data.labelType;
        const labelName = labelNode.data.labelName;
        const labelAttributes = labelNode.data.labelAttributes;
        const labelDefinition = labelDefinitionsByName[labelName];
        if (!labelDefinition) {
            utils_1.markLabelNodeAsErroneous(vFile, labelNode, types_1.LabelErrorType.MISSING_DEFINITION, `Label ${labelName} cannot be used because it does not exist in the linked narrative schemas or is not valid.`);
            return;
        }
        if (labelType === types_1.LabelType.SINGLE) {
            if (!labelDefinition.data.single) {
                utils_1.markLabelNodeAsErroneous(vFile, labelNode, types_1.LabelErrorType.KIND_MISUSE, `Label ${labelName} cannot be used as single (no-paired), according to the linked narrative schemas.`);
                return;
            }
            try {
                const html = renderHtmlTemplate_1.default(labelDefinition.data.single.htmlTemplate, labelName, labelType, labelAttributes);
                labelNode.data.html = html;
            }
            catch (e) {
                utils_1.markLabelNodeAsErroneous(vFile, labelNode, types_1.LabelErrorType.HTML_TEMPLATE_EXCEPTION, `Label ${labelName} cannot be converted to html. Is htmlTemplate correct?`);
            }
            return;
        }
        if (!labelDefinition.data.paired) {
            utils_1.markLabelNodeAsErroneous(vFile, labelNode, types_1.LabelErrorType.KIND_MISUSE, `Label ${labelName} cannot be used as paired, according to the linked narrative schemas.`);
            return;
        }
        try {
            const html = renderHtmlTemplate_1.default(labelDefinition.data.paired.htmlTemplate, labelName, labelType, labelAttributes);
            labelNode.data.html = html;
        }
        catch (e) {
            utils_1.markLabelNodeAsErroneous(vFile, labelNode, types_1.LabelErrorType.HTML_TEMPLATE_EXCEPTION, `Label ${labelName} cannot be converted to html. Is htmlTemplate correct?`);
        }
    });
};
//# sourceMappingURL=visitAndExtractHtml.js.map